# Patching guideline for python :
# - no big patch with invasive change not
#     approved by upstream ( ie not coming from upstream svn )
# - small bugfix must be sent to upstream and approved if they
#     change any interface
# - all patchs should be commented ( unless for security,
#     as they are usually easy to spot )

%define docver  2.7.18
%define dirver  2.7

%define pybasever	%{dirver}

%define lib_major       %{dirver}
%define lib_name_orig   libpython
%define lib_name        %mklibname %{name} %{lib_major}
%define dev_name        %mklibname %{name} -d

%define arch_has_valgrind 1
%ifarch %arm %mips aarch64
%define arch_has_valgrind 0
%endif

%if %arch_has_valgrind
%bcond_without  valgrind
%else
%bcond_with     valgrind
%endif

%bcond_with tkinter

# Whether to use RPM build wheels from the python-{pip,setuptools}-wheel package
# Uses upstream bundled prebuilt wheels otherwise
# setuptools >= 45.0 no longer support Python 2.7, hence disabled
%bcond_with rpmwheels

# Some defines to ease files list
%define pylibdir %{_libdir}/python%{dirver}
%define dynload_dir %{pylibdir}/lib-dynload
%define site_packages %{pylibdir}/site-packages

# Some of the files below /usr/lib/pythonMAJOR.MINOR/test  (e.g. bad_coding.py)
# are deliberately invalid, leading to SyntaxError exceptions if they get
# byte-compiled.
#
# These errors are ignored by the normal python build, and aren't normally a
# problem in the buildroots since /usr/bin/python isn't present.
#
# So we disable here brp-python-bytecompile
#
%global __brp_python_bytecompile %nil

%define __python %{__python2}


Summary:        An interpreted, interactive object-oriented programming language
Name:           python
Version:        2.7.18
%define subrel 2
Release:        %mkrel 15
License:        Modified CNRI Open Source License
Group:          Development/Python
Url:            http://www.python.org/

Source0:        http://www.python.org/ftp/python/%{version}/Python-%{version}.tar.xz
Source1:        http://www.python.org/ftp/python/doc/%{docver}/python-%{docver}-docs-html.tar.bz2

Patch0:         python-2.7.14-module-linkage.patch

# Don't include /usr/local/* in search path
Patch3:         python-2.7.12-no-local-incpath.patch

# Support */lib64 convention on x86_64, sparc64, etc.
# similar patches reported upstream on http://bugs.python.org/issue1294959
Patch4:         python-lib64.patch

# add mandriva to the list of supported distribution, applied upstream
Patch10:        python-2.7.12-detect-mandriva.patch

# Backport upstream commit
# https://github.com/python/cpython/commit/3f135c073a53793ec68902f6b513934ddff47235
Patch13:	0001-bpo-44734-Fix-precision-in-turtle-tests.patch

# More precision fixes
Patch14:	0002-More-floating-point-precision-fixes-for-turtle-tests.patch

# From Fedora
# Fixup distutils/unixccompiler.py to remove standard library path from rpath
Patch15: python-2.6.4-distutils-rpath.patch

# from Fedora, fixes gettext.py parsing of Plural-Forms: header (fixes mdv bugs #49475, #44088)
# to send upstream
Patch16:        python-2.7.14-plural-fix.patch

# ffi checks for MIPS_LINUX instead of MIPS
Patch23:        python-2.7.12-mips-ffi.patch

# do not use uname -m to get the exact name on mips/arm
Patch24:        python_arch.patch

# fix https://bugs.mageia.org/show_bug.cgi?id=481
# mdv bug #62281
# patch to cope with lack of /dev/shm in iurt
Patch25:        python-2.7.14-skip-shm-test.patch

Patch130:       python-2.7.14-check-for-XML_SetHashSalt.patch

# 00189 #
# Instead of bundled wheels, use our RPM packaged wheels from
# /usr/share/python-wheels
Patch189:       00189-use-rpm-wheels.patch

# Enable loading sqlite extensions. This patch isn't needed for
# python3.spec, since Python 3 has a configuration option for this.
# rhbz#1066708
# Patch provided by John C. Peterson
# Note (05/12/2017): this patch added in rev. 666153 (21/08/2014) - but never applied up to now
Patch193:       00193-enable-loading-sqlite-extensions.patch

# (tv) make platform supports Mageia:
Patch200:       add-mga-support.patch

# Improve documentation warning against the possible zip bombs
Patch350:       CVE-2019-9674-zip-bomb.patch
# 00351 #
# Avoid infinite loop when reading specially crafted TAR files using the tarfile module
# (CVE-2019-20907).
# See: https://bugs.python.org/issue39017
Patch351:       00351-cve-2019-20907-fix-infinite-loop-in-tarfile.patch
# Fixes Python urrlib allowed an HTTP server to conduct Regular
# Expression Denial of Service (ReDoS)
Patch352:       CVE-2020-8492-urllib-ReDoS.patch
# explain that the orderness of the of the result is system-dependant in Doc/library/glob.rst
Patch353:       CVE-2019-17514.patch
# 00354 # 9e9d2c6106446ad107ca1bb6729883c76fefc6eb
# Reject control chars in HTTP method in httplib.putrequest to prevent
# HTTP header injection
#
# Backported from Python 3.5-3.10 (and adjusted for py2's single-module httplib):
# - https://bugs.python.org/issue39603
# - https://github.com/python/cpython/pull/18485 (3.10)
# - https://github.com/python/cpython/pull/21946 (3.5)
#
# Co-authored-by: AMIR <31338382+amiremohamadi@users.noreply.github.com>
Patch354:       00354-cve-2020-26116-http-request-method-crlf-injection-in-httplib.patch

# 00355 # fde656e7116767a761720970ee750ecda6774e71
# No longer call eval() on content received via HTTP in the CJK codec tests
# Backported from the python3 branches upstream: https://bugs.python.org/issue41944
# Resolves: https://bugzilla.redhat.com/show_bug.cgi?id=1889886
Patch355:       00355-CVE-2020-27619.patch

Patch366:	00366-CVE-2021-3733.patch
Patch368:	00368-CVE-2021-3737.patch
Patch372:	00372-CVE-2021-4189.patch
Patch377:	00377-CVE-2022-0391.patch

# 00382 # 65796028be4b28aaf027963d6fb2ef4c219e73dc
# Make mailcap refuse to match unsafe filenames/types/params (GH-91993)
#
# Upstream: https://github.com/python/cpython/issues/68966
#
# Tracker bug: https://bugzilla.redhat.com/show_bug.cgi?id=2075390
#
# Backported from python3.
Patch382: 00382-cve-2015-20107.patch

Patch500:       CVE-2017-18207.patch
# CVE-2021-3177: Replace snprintf with Python unicode formatting in ctypes param reprs
#
# Backport of Python3 commit 916610ef90a0d0761f08747f7b0905541f0977c7:
# https://bugs.python.org/issue42938
# https://github.com/python/cpython/pull/24239
Patch501:	CVE-2021-3177.patch
Patch502:	CVE-2021-23336-only-amp-as-query-sep.patch
Patch503:	CVE-2021-28861-double-slash-path.patch
Patch504:	CVE-2022-45061-DoS-by-IDNA-decode.patch
Patch505:	CVE-2022-48565-plistlib-XML-vulns.patch
Patch506:	CVE-2022-48566-compare_digest-more-constant.patch
Patch507:	CVE-2023-24329-blank-URL-bypass.patch
Patch508:	CVE-2023-40217-avoid-ssl-pre-close.patch
Patch509:	0001-3.9-gh-109858-Protect-zipfile-from-quoted-overlap-zi.patch

Conflicts:      tkinter < %{version}
Conflicts:      python-devel < 2.7-6
Requires:       %{lib_name} = %{version}-%{release}
BuildRequires:  blt
BuildRequires:  db5-devel
BuildRequires:  emacs-bin
BuildRequires:  git-core
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(libffi)
BuildRequires:  gdbm-devel
BuildRequires:  gmp-devel
BuildRequires:  pkgconfig(ncursesw)
BuildRequires:  pkgconfig(openssl) >= 1.1
BuildRequires:  readline-devel
BuildRequires:  termcap-devel
%if %{with tkinter}
BuildRequires:  pkgconfig(tk)
%endif
BuildRequires:  tix
BuildRequires:  autoconf2.5
BuildRequires:  bzip2-devel
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  emacs
%if %{with valgrind}
BuildRequires:  pkgconfig(valgrind)
%endif
%if %{with rpmwheels}
BuildRequires:  python-setuptools-wheel
BuildRequires:  python-pip-wheel
%endif
#BuildRequires:  python2
BuildRequires:	pkgconfig(libnsl)
BuildRequires:	pkgconfig(libtirpc)

# (2010/03/21, misc: interfere with test__all )
BuildConflicts: python-pyxml

Provides:       python(abi) = %dirver
Provides:	/usr/bin/python2
Provides:	/usr/bin/python%{dirver}
%rename python-ctypes
%rename python-elementtree
Obsoletes:      python-base < 2.6
Provides:       python-base = %version
Requires:       python2-rpm-macros
Provides:       python2 = %version-%{release}

# Previously, this was required for our rewheel patch to work.
# This is technically no longer needed, but we keep it recommended
# for the developer experience.
Recommends:     python2-setuptools
Recommends:     python2-pip

%if ! %{with tkinter}
Obsoletes:	tkinter < %{version}-%{release}
Obsoletes:	tkinter-apps < %{version}-%{release}
%endif

%description
Python is an interpreted, interactive, object-oriented programming
language often compared to Tcl, Perl, Scheme or Java. Python includes
modules, classes, exceptions, very high level dynamic data types and
dynamic typing. Python supports interfaces to many system calls and
libraries, as well as to various windowing systems (X11, Motif, Tk,
Mac and MFC).

Programmers can write new built-in modules for Python in C or C++.
Python can be used as an extension language for applications that
need a programmable interface. This package contains most of the
standard Python modules, as well as modules for interfacing to the
Tix widget set for Tk and RPM.

Note that documentation for Python is provided in the python-docs
package.


%package -n     %{lib_name}
Summary:        Shared libraries for Python %{version}
Group:          System/Libraries
Requires:       %{lib_name}-stdlib = %{version}-%{release}

%description -n %{lib_name}
This packages contains Python shared object library.  Python is an
interpreted, interactive, object-oriented programming language often
compared to Tcl, Perl, Scheme or Java.

%package -n     %{lib_name}-stdlib
Summary:        Python %{version} standard library
Group:          Development/Python
%if %{with rpmwheels}
Requires:       python-setuptools-wheel
Requires:       python-pip-wheel
%else
Provides:       bundled(python2-pip) = 19.2.3
Provides:       bundled(python2-setuptools) = 41.2.0
%endif
# both main and -stdlib provides python(abi) == 2.7 so make sure main pkg is
# installed: /usr/bin/python2: bad interpreter: No such file or directory (mga#24573)
Requires:       python2 = %{version}-%{release}
Conflicts:      python < 2.7.11-10
Conflicts:      %{dev_name} < 2.7.11-10

%description -n %{lib_name}-stdlib
This package contains Python 2.7's standard library.
It is normally not used on its own, but as a dependency of Python %{version}. 


%package -n     %{lib_name}-testsuite
Summary:        Testsuite for the Python %{version} standard library
Group:          Development/Python
Conflicts:      python < 2.7.11-10
Conflicts:      %{dev_name} < 2.7.11-10
Requires:       %{lib_name}-stdlib = %{version}-%{release}
Requires:       %{lib_name} = %{version}-%{release}
%if %{with tkinter}
Recommends:     tkinter
%endif
Provides:       python2-testsuite = %{version}-%{release}

%description -n %{lib_name}-testsuite
The complete testsuite for the Python standard library.
It is normally not used on its own, but as a dependency of Python %{version}. 


%package -n     %{dev_name}
Summary:        The libraries and header files needed for Python development
Group:          Development/Python
Requires:       %{name} = %version
Requires:       %{lib_name} = %{version}-%{release}
Requires:       python-rpm-macros
Requires:       python2-rpm-macros
Provides:       %{name}-devel = %{version}-%{release}
Provides:       python2-devel = %{version}-%{release}
Provides:       %{lib_name_orig}-devel = %{version}-%{release}
Recommends:     %{lib_name}-testsuite
Recommends:     python-docs

%description -n %{dev_name}
The Python programming language's interpreter can be extended with
dynamically loaded extensions and can be embedded in other programs.
This package contains the header files and libraries needed to do
these types of tasks.

Install %{dev_name} if you want to develop Python extensions.  The
python package will also need to be installed.  You'll probably also
want to install the python-docs package, which contains Python
documentation.


%package        docs
Summary:        Documentation for the Python programming language
Group:          Development/Python
Requires:       python2 = %version
Requires:       xdg-utils
BuildArch:      noarch

%description    docs
The python-docs package contains documentation on the Python
programming language and interpreter.  The documentation is provided
in ASCII text files and in LaTeX source files.

Install the python-docs package if you'd like to use the documentation
for the Python language.

%if %{with tkinter}
%package -n     tkinter
Summary:        A graphical user interface for the Python scripting language
Group:          Development/Python
Requires:       python2 = %version
Requires:       tcl tk
Provides:       python2-tkinter
Conflicts:      python < 2.7.11-10

%description -n tkinter
The Tkinter (Tk interface) program is an graphical user interface for
the Python scripting language.

You should install the tkinter package if you'd like to use a graphical
user interface for Python programming.


%package -n     tkinter-apps
Summary:        Various applications written using tkinter
Group:          Development/Python
Requires:       tkinter

%description -n tkinter-apps
Various applications written using tkinter.
%endif


%prep
%setup -q -n Python-%{version}
%patch -P0 -p1
# local include
%patch -P3 -p1
# lib64
%patch -P4 -p1

# add mandriva to the list of supported distribution
%patch -P10 -p1

%patch -P13 -p1
%ifarch %ix86
%patch -P14 -p1
%endif
%patch -P15 -p1
%patch -P16 -p1
%patch -P23 -p1
%patch -P24 -p1
%patch -P25 -p1
%patch -P130 -p1
%if %{with rpmwheels}
%patch -P189 -p1
rm Lib/ensurepip/_bundled/*.whl
%endif
%patch -P193 -p1

%patch -P200 -p1
%patch -P350 -p1
# Patch 351 adds binary file for testing. We need to apply it using Git.
git apply %{PATCH351}
%patch -P352 -p1
%patch -P353 -p1
%patch -P354 -p1
%patch -P355 -p1
%patch -P366 -p1
%patch -P368 -p1
%patch -P372 -p1
%patch -P377 -p1
%patch -P382 -p1
%patch -P500 -p1
%patch -P501 -p1
%patch -P502 -p1
%patch -P503 -p1
%patch -P504 -p1
%patch -P505 -p1
%patch -P506 -p1
%patch -P507 -p1
%patch -P508 -p1
%patch -P509 -p1

# drop Autoconf version requirement
sed -i 's/^AC_PREREQ/dnl AC_PREREQ/' configure.ac

# docs
mkdir html
bzcat %{SOURCE1} | tar x  -C html
find html -type d |xargs chmod 755
find html -type f |xargs chmod 644

find . -type f -print0 | xargs -0 perl -p -i -e 's@/usr/local/bin/python@/usr/bin/python@'

cat > README.mga << EOF
Python interpreter support readline completion by default.
This is only used with the interpreter. In order to remove it,
you can :
1) unset PYTHONSTARTUP when you login
2) create a empty file \$HOME/.pythonrc.py
3) change %{_sysconfdir}/pythonrc.py
EOF

# make sur the IN.py TYPES.py and DLFCN.py are correct
# for current arch otherwise things will start failing
# in weird ways
%if 0
pushd Lib/plat-linux2/
%{__python2} ../../Tools/scripts/h2py.py -i '(u_long)' /usr/include/sys/types.h /usr/include/netinet/in.h /usr/include/dlfcn.h
popd
%endif

%build
autoreconf -fi

rm -f Modules/Setup.local
cat > Modules/Setup.local << EOF
linuxaudiodev linuxaudiodev.c
EOF

# We need -fwrapv
# https://bugs.python.org/issue34096
export OPT="%{optflags} -D_GNU_SOURCE -fPIC -fwrapv"
export CFLAGS="%{optflags} -D_GNU_SOURCE -fPIC -fwrapv"
export CXXFLAGS="%{optflags} -D_GNU_SOURCE -fPIC -fwrapv"

# to fix curses module build
# https://bugs.mageia.org/show_bug.cgi?id=5524
export CPPFLAGS="-I/usr/include/ncursesw"

autoreconf -vfi
# Remove -Wl,--no-undefined in accordance with MGA #9395 and MGA #10102:
# https://bugs.mageia.org/show_bug.cgi?id=9395
# https://bugs.mageia.org/show_bug.cgi?id=10102
%define _disable_ld_no_undefined 1

# see https://qa.mandriva.com/show_bug.cgi?id=48570
# for wide unicode support
%configure  --with-threads \
        --enable-unicode=ucs4 \
        --with-dbmliborder=gdbm \
        --enable-ipv6 \
        --enable-shared \
        --with-system-expat \
        --with-system-ffi \
%if %{with valgrind}
        --with-valgrind
%endif

# (misc) if the home is nfs mounted, rmdir fails due to delay
export TMP="/tmp" TMPDIR="/tmp"
make

%check
# (misc) if the home is nfs mounted, rmdir fails
export TMP="/tmp" TMPDIR="/tmp"

# all tests must pass
CUSTOM_TEST=""
%ifarch %arm
# don't know if it's a python issue or a toolchain issue :(
# test test_float failed -- Traceback (most recent call last):
#  File "/home/rtp/deb/python2.6-2.6.4/Lib/test/test_float.py", line 665, in test_from_hex
#    self.identical(fromHex('0x0.ffffffffffffd6p-1022'), MIN-3*TINY)
#  File "/home/rtp/deb/python2.6-2.6.4/Lib/test/test_float.py", line 375, in identical
#    self.fail('%r not identical to %r' % (x, y))
# AssertionError: 2.2250738585071999e-308 not identical to 2.2250738585071984e-308
CUSTOM_TEST="$CUSTOM_TEST test_float test_cmath"
%endif

%ifarch aarch64
CUSTOM_TEST="$CUSTOM_TEST test_ctypes"
%endif

# tests failing
CUSTOM_TEST="$CUSTOM_TEST test_distutils test_ftplib test_minidom test_urllib2_localnet test_xml_etree test_xml_etree_c"

# if a test doesn't pass, it can be disabled with -x test, but this should be documented in the
# spec file, and a bug should be reported if possible ( on python side )
# (misc, 29/10/2010) "test_site" fail due to one of our patch, will fix later
# (05/12/2017) "test_tuple" fails on i586 only, no crash though
# (01/05/2018) "test_ssl" fails on BS "UnicodeEncodeError"
WITHIN_PYTHON_RPM_BUILD= make test TESTOPTS="-w -l -x test_ssl test_site test_tuple $CUSTOM_TEST"

%install
mkdir -p %{buildroot}%{_prefix}/lib/python%{dirver}

%if "%{_lib}" == "lib64"
mkdir -p %{buildroot}%{_prefix}/lib/python%{dirver}/site-packages
%endif

# fix Makefile to get rid of reference to distcc
perl -pi -e "/^CC=/ and s/distcc/gcc/" Makefile

# set the install path
echo '[install_scripts]' >setup.cfg
echo 'install_dir='"%{buildroot}/usr/bin" >>setup.cfg

# python is not GNU and does not know fsstd
mkdir -p %{buildroot}%{_mandir}
%make_install

(cd %{buildroot}%{_libdir}; ln -sf libpython%{lib_major}.so.* libpython%{lib_major}.so)

# Provide a libpython%{dirver}.so symlink in /usr/lib/puthon*/config, so that
# the shared library could be found when -L/usr/lib/python*/config is specified
(cd %{buildroot}%{_libdir}/python%{dirver}/config; ln -sf ../../libpython%{lib_major}.so .)

#"  this comment is just here because vim syntax higlighting is confused by the previous snippet of lisp

# smtpd proxy
mv -f %{buildroot}%{_bindir}/smtpd.py $RPM_BUILD_ROOT%{_libdir}/python%{dirver}/

%if %{with tkinter}
# pynche
cat << EOF > %{buildroot}%{_bindir}/pynche
#!/bin/bash
exec %{_libdir}/python%{dirver}/site-packages/pynche/pynche
EOF
rm -f Tools/pynche/*.pyw
cp -r Tools/pynche %{buildroot}%{_libdir}/python%{dirver}/site-packages/

chmod 755 %{buildroot}%{_bindir}/pynche

ln -f Tools/pynche/README Tools/pynche/README.pynche
%endif

%if %{with valgrind}
install Misc/valgrind-python.supp -D %{buildroot}%{_libdir}/valgrind/valgrind-python.supp
%endif

%if %{with tkinter}
mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-tkinter.desktop << EOF
[Desktop Entry]
Name=IDLE
Comment=IDE for Python
Exec=%{_bindir}/idle
Icon=development_environment_section
Terminal=false
Type=Application
Categories=Development;IDE;
EOF
%endif

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-%{name}-docs.desktop << EOF
[Desktop Entry]
Name=Python documentation
Comment=Python complete reference
Exec=%{_bindir}/xdg-open %_defaultdocdir/%{name}-docs/index.html
Icon=documentation_section
Terminal=false
Type=Application
Categories=Documentation;
EOF


# fix non real scripts
chmod 644 %{buildroot}%{_libdir}/python*/test/test_{binascii,grp,htmlparser}.py*
# fix python library not stripped
chmod u+w %{buildroot}%{_libdir}/libpython%{lib_major}.so.1.0


mkdir -p %{buildroot}%{_sysconfdir}/profile.d/

cat > %{buildroot}%{_sysconfdir}/profile.d/30python2.sh << 'EOF'
if [ -f $HOME/.pythonrc.py ] ; then
        export PYTHONSTARTUP=$HOME/.pythonrc.py
else
        export PYTHONSTARTUP=/etc/pythonrc.py
fi
EOF

cat > %{buildroot}%{_sysconfdir}/profile.d/30python2.csh << 'EOF'
if ( -f ${HOME}/.pythonrc.py ) then
        setenv PYTHONSTARTUP ${HOME}/.pythonrc.py
else
        setenv PYTHONSTARTUP /etc/pythonrc.py
endif
EOF

cat > %{buildroot}%{_sysconfdir}/pythonrc.py << EOF
try:
    get_ipython()
except:
    try:
        # this add completion to python interpreter
        import readline
        import rlcompleter
        # see readline man page for this
        readline.parse_and_bind("set show-all-if-ambiguous on")
        readline.parse_and_bind("tab: complete")
    except:
        pass
# you can place a file .pythonrc.py in your home to overrides this one
# but then, this file will not be sourced
EOF

%if ! %{with tkinter}
rm -rf %{buildroot}%{_bindir}/idle
rm -rf %{buildroot}%{pylibdir}/{idlelib,lib-tk}
%endif

# Do bytecompilation with the newly installed interpreter.
# compile *.pyo
find %{buildroot}%{_libdir}/python%{pybasever} -type f -a -name "*.py" -print0 | \
    LD_LIBRARY_PATH="%{buildroot}%{dynload_dir}/:%{buildroot}%{_libdir}" \
    PYTHONPATH="%{buildroot}%{_libdir}/python%{pybasever} %{buildroot}%{_libdir}/python%{pybasever}/site-packages" \
    xargs -0 %{buildroot}%{_bindir}/python%{pybasever} -O -c 'import py_compile, sys; [py_compile.compile(f, dfile=f.partition("%{buildroot}")[2]) for f in sys.argv[1:]]' || :
# compile *.pyc
find %{buildroot}%{_libdir}/python%{pybasever} -type f -a -name "*.py" -print0 | \
    LD_LIBRARY_PATH="%{buildroot}%{dynload_dir}/:%{buildroot}%{_libdir}" \
    PYTHONPATH="%{buildroot}%{_libdir}/python%{pybasever} %{buildroot}%{_libdir}/python%{pybasever}/site-packages" \
    xargs -0 %{buildroot}%{_bindir}/python%{pybasever} -c 'import py_compile, sys; [py_compile.compile(f, dfile=f.partition("%{buildroot}")[2]) for f in sys.argv[1:]]' || :

# Fix shebangs with the newly installed interpreter.
LD_LIBRARY_PATH="%{buildroot}%{dynload_dir}/:%{buildroot}%{_libdir}" \
PYTHONPATH="%{buildroot}%{_libdir}/python%{pybasever} %{buildroot}%{_libdir}/python%{pybasever}/site-packages" \
  %{buildroot}%{_bindir}/python%{pybasever} ./Tools/scripts/pathfix.py \
    -i "%{_bindir}/python%{pybasever}" \
    %{buildroot}%{_bindir} %{buildroot}%{_libdir}/python%{pybasever} \
%if %{with tkinter}
    %{buildroot}%{_bindir}/idle \
    %{buildroot}%{_libdir}/python%{dirver}/site-packages/pynche/pynche \
%endif
    %nil

# Make python-devel multilib-ready (rhbz#192747, rhbz#139911)
mv %{buildroot}%{_includedir}/python%{pybasever}/pyconfig.h \
   %{buildroot}%{_includedir}/python%{pybasever}/pyconfig-%{__isa_bits}.h
cat > %{buildroot}%{_includedir}/python%{pybasever}/pyconfig.h << EOF
#include <bits/wordsize.h>

#if __WORDSIZE == 32
#include "pyconfig-32.h"
#elif __WORDSIZE == 64
#include "pyconfig-64.h"
#else
#error "Unknown word size"
#endif
EOF

# Make sure distutils looks at the right pyconfig.h file (rhbz#201434)
# Similar for sysconfig: sysconfig.get_config_h_filename tries to locate
# pyconfig.h so it can be parsed, and needs to do this at runtime in site.py
# when python starts up.
sed -i -e "s/'pyconfig.h'/'pyconfig-%{__isa_bits}.h'/" \
  %{buildroot}%{pylibdir}/distutils/sysconfig.py \
  %{buildroot}%{pylibdir}/sysconfig.py

# remove/rename files as python3 will be the default one
rm -rf %{buildroot}%{_bindir}/python{,-config}
rm -rf %{buildroot}%{_libdir}/pkgconfig/python.pc
rm -rf %{buildroot}%{_mandir}/man1/python.1*
for i in 2to3 pydoc; do
  mv %{buildroot}%{_bindir}/$i %{buildroot}%{_bindir}/$i-%{dirver}
done

# clean
find %{buildroot} -name "*~" -delete
rm -f %{buildroot}%{pylibdir}/LICENSE.txt

%files
%doc README.mga
%config(noreplace) %{_sysconfdir}/profile.d/30python2.*
%config(noreplace) %{_sysconfdir}/pythonrc.py

%{_bindir}/python2
%{_bindir}/python%{dirver}
%{_bindir}/pydoc-%{dirver}
%{_bindir}/2to3-%{dirver}
%{_mandir}/man1/python2*.1*

%files -n %{lib_name}-stdlib
%license LICENSE
%dir %{pylibdir}
%dir %{dynload_dir}
%{dynload_dir}/Python-%{version}-py%{dirver}.egg-info
%{dynload_dir}/_bisect.so
%{dynload_dir}/_bsddb.so
%{dynload_dir}/_codecs_cn.so
%{dynload_dir}/_codecs_hk.so
%{dynload_dir}/_codecs_iso2022.so
%{dynload_dir}/_codecs_jp.so
%{dynload_dir}/_codecs_kr.so
%{dynload_dir}/_codecs_tw.so
%{dynload_dir}/_collections.so
%{dynload_dir}/_csv.so
%{dynload_dir}/_ctypes.so
%{dynload_dir}/_curses.so
%{dynload_dir}/_curses_panel.so
%{dynload_dir}/_elementtree.so
%{dynload_dir}/_functools.so
#%%{dynload_dir}/_hashlib.so
%{dynload_dir}/_heapq.so
%{dynload_dir}/_hotshot.so
%{dynload_dir}/_io.so
%{dynload_dir}/_json.so
%{dynload_dir}/_locale.so
%{dynload_dir}/_lsprof.so
%{dynload_dir}/_md5.so
%{dynload_dir}/_multibytecodec.so
%{dynload_dir}/_multiprocessing.so
%{dynload_dir}/_random.so
%{dynload_dir}/_sha.so
%{dynload_dir}/_sha256.so
%{dynload_dir}/_sha512.so
%{dynload_dir}/_socket.so
%{dynload_dir}/_sqlite3.so
%{dynload_dir}/_ssl.so
%{dynload_dir}/_struct.so
%{dynload_dir}/array.so
%{dynload_dir}/audioop.so
%{dynload_dir}/binascii.so
%{dynload_dir}/bz2.so
%{dynload_dir}/cPickle.so
%{dynload_dir}/cStringIO.so
%{dynload_dir}/cmath.so
%{dynload_dir}/crypt.so
%{dynload_dir}/datetime.so
%{dynload_dir}/dbm.so
%ifarch %{ix86} %{arm}
%{dynload_dir}/dl.so
%endif
%{dynload_dir}/fcntl.so
%{dynload_dir}/future_builtins.so
%{dynload_dir}/gdbm.so
%{dynload_dir}/grp.so
%ifarch %{ix86} %{arm}
%{dynload_dir}/imageop.so
%endif
%{dynload_dir}/itertools.so
%{dynload_dir}/math.so
%{dynload_dir}/mmap.so
%{dynload_dir}/nis.so
%{dynload_dir}/operator.so
%{dynload_dir}/ossaudiodev.so
%{dynload_dir}/parser.so
%{dynload_dir}/pyexpat.so
%{dynload_dir}/readline.so
%{dynload_dir}/resource.so
%{dynload_dir}/select.so
%{dynload_dir}/spwd.so
%{dynload_dir}/strop.so
%{dynload_dir}/syslog.so
%{dynload_dir}/termios.so
%{dynload_dir}/time.so
%{dynload_dir}/unicodedata.so
%{dynload_dir}/zlib.so
%dir %{site_packages}
%{site_packages}/README
%{pylibdir}/*.py*
%{pylibdir}/*.doc
%{pylibdir}/wsgiref.egg-info
%dir %{pylibdir}/bsddb
%{pylibdir}/bsddb/*.py*
%{pylibdir}/compiler
%dir %{pylibdir}/ctypes
%{pylibdir}/ctypes/*.py*
%{pylibdir}/ctypes/macholib
%{pylibdir}/curses
%dir %{pylibdir}/distutils
%{pylibdir}/distutils/*.py*
%{pylibdir}/distutils/README
%{pylibdir}/distutils/command
%exclude %{pylibdir}/distutils/command/wininst-*.exe
%dir %{pylibdir}/email
%{pylibdir}/email/*.py*
%{pylibdir}/email/mime
%{pylibdir}/encodings
%{pylibdir}/hotshot
%{pylibdir}/importlib
%dir %{pylibdir}/json
%{pylibdir}/json/*.py*
%{pylibdir}/lib2to3
%exclude %{pylibdir}/lib2to3/tests
%{pylibdir}/logging
%{pylibdir}/multiprocessing
%{pylibdir}/plat-linux2
%{pylibdir}/pydoc_data
%dir %{pylibdir}/sqlite3
%{pylibdir}/sqlite3/*.py*
%dir %{pylibdir}/test
%{pylibdir}/test/test_support.py*
%{pylibdir}/test/__init__.py*
%{pylibdir}/unittest/*.py*
%{pylibdir}/wsgiref
%{pylibdir}/xml
%if "%{_lib}" == "lib64"
%dir %{_prefix}/lib/python%{dirver}
%dir %{_prefix}/lib/python%{dirver}/site-packages
%endif

# "Makefile" and the config.h file are needed by
# distutils/sysconfig.py:_init_posix(), so we include them in the libs
# package, along with their parent directories (RH bug#531901):
%dir %{_libdir}/python%{dirver}/config
%{_libdir}/python%{dirver}/config/Makefile
%dir %{_includedir}/python%{dirver}
%{_includedir}/python%{dirver}/pyconfig-%{__isa_bits}.h

%dir %{pylibdir}/ensurepip/
%{pylibdir}/ensurepip/*.py*
%if %{with rpmwheels}
%exclude %{pylibdir}/ensurepip/_bundled
%else
%dir %{pylibdir}/ensurepip/_bundled
%{pylibdir}/ensurepip/_bundled/*.whl
%endif


%files -n %{lib_name}
%{_libdir}/libpython*.so.1*


%files -n %{dev_name}
%{_libdir}/libpython*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/python%{dirver}
%{_libdir}/python%{dirver}/config/*
%{_bindir}/python%{dirver}-config
%{_bindir}/python2-config
%exclude %{_libdir}/python%{dirver}/config/Makefile
%exclude %{_includedir}/python%{dirver}/pyconfig-%{__isa_bits}.h

%if %{with valgrind}
%{_libdir}/valgrind/valgrind-python.supp
%endif


%files -n %{lib_name}-testsuite
%{pylibdir}/bsddb/test
%{pylibdir}/ctypes/test
%{pylibdir}/distutils/tests
%{pylibdir}/email/test
%{pylibdir}/json/tests
%{pylibdir}/lib2to3/tests
%{pylibdir}/sqlite3/test
%{pylibdir}/test/*
%{pylibdir}/unittest/test
# These two are shipped in the main subpackage:
%exclude %{pylibdir}/test/test_support.py*
%exclude %{pylibdir}/test/__init__.py*
%{dynload_dir}/_ctypes_test.so
%{dynload_dir}/_testcapi.so


%files docs
%doc html/*/*
%{_datadir}/applications/%{_real_vendor}-%{name}-docs.desktop

%if %{with tkinter}
%files -n tkinter
%dir %{pylibdir}/lib-tk
%{pylibdir}/lib-tk/*.py*
%{pylibdir}/lib-tk/test/
%{dynload_dir}/_tkinter.so
%{pylibdir}/idlelib
%{site_packages}/pynche


%files -n tkinter-apps
%{_bindir}/idle
%{_bindir}/pynche
%{_datadir}/applications/%{_real_vendor}-tkinter.desktop
%endif


%changelog
* Tue Mar 26 2024 ns80 <ns80> 2.7.18-15.2.mga9
+ Revision: 2052245
- add a patch from Debian for CVE-2024-0450 (mga#32998)
- add patches from openSUSE for CVE-2022-45061, CVE-2022-48565, CVE-2022-48566, CVE-2023-24329 and CVE-2023-40217 (mga#31000)

* Sat Nov 19 2022 wally <wally> 2.7.18-15.mga9
+ Revision: 1909005
- build without tkinter

* Sun Oct 09 2022 wally <wally> 2.7.18-14.mga9
+ Revision: 1895663
- add patch via SUSE to fix CVE-2021-28861 (mga#30572)

* Tue Oct 04 2022 wally <wally> 2.7.18-13.mga9
+ Revision: 1894587
- add Fedora patch to fix CVE-2015-20107 (mga#30572)

* Tue Sep 06 2022 neoclust <neoclust> 2.7.18-12.mga9
+ Revision: 1884358
- Add P505: Fixes CVE-2021-4189 (mga#30043)
  Add P506: Fixes CVE-2022-0391 (mga#30043)

* Sat Apr 16 2022 wally <wally> 2.7.18-11.mga9
+ Revision: 1850708
- skip failing tests for now
- bootstrap without python2
+ tmb <tmb>
- rebuild for openssl 3.0.0

* Thu Sep 30 2021 wally <wally> 2.7.18-10.mga9
+ Revision: 1746976
- backport upstream patch to fix precision in turtle tests (bpo#44734)
- add Fedora patch to fix RPATH issue
+ neoclust <neoclust>
- Add P503/504: Fixes CVE-2021-373[37] (mga#29494)
- Add P502: Fixes CVE-2021-23336 (mga#28408)
+ luigiwalser <luigiwalser>
- add patch from fedora to fix CVE-2020-27619

* Mon Feb 01 2021 neoclust <neoclust> 2.7.18-7.mga8
+ Revision: 1674388
- Add P501 to fix CVE-2021-3177 (mga#28204)

* Sat Jan 02 2021 wally <wally> 2.7.18-6.mga8
+ Revision: 1668209
- BR libtirpc and libnsl

* Fri Nov 20 2020 daviddavid <daviddavid> 2.7.18-5.mga8
+ Revision: 1647837
- add fedora patch to fix CVE-2020-26116 (mga#26268)

* Sat Oct 03 2020 joequant <joequant> 2.7.18-4.mga8
+ Revision: 1632008
- remove emacs python mode since new emacs has better mode installed

* Thu Jul 30 2020 luigiwalser <luigiwalser> 2.7.18-3.mga8
+ Revision: 1609897
- add patch from ubuntu to improve documentation for CVE-2019-17514

* Thu Jul 30 2020 daviddavid <daviddavid> 2.7.18-2.mga8
+ Revision: 1609868
- add patches to fix CVE-2019-9674, CVE-2019-20907 and CVE-2020-8492 (mga#26268)

* Wed May 06 2020 wally <wally> 2.7.18-1.mga8
+ Revision: 1581330
- new version 2.7.18
- use bundled wheels (setuptools >= 45.0 no longer supports py2.7)
- replace deprecated %%configure2_5x
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Sat Jan 04 2020 tv <tv> 2.7.17-3.mga8
+ Revision: 1476442
- rebuild with new readline

* Fri Nov 01 2019 daviddavid <daviddavid> 2.7.17-2.mga8
+ Revision: 1457253
- new version: 2.7.17, fixes CVE-2019-16056 and CVE-2019-16935 (mga#25641)

* Sat Aug 31 2019 wally <wally> 2.7.16-3.mga8
+ Revision: 1435998
- remove python symlinks (prepare for switching to python3)
- add 2.7 suffix to 2to3 and pydoc

* Sat May 04 2019 daviddavid <daviddavid> 2.7.16-2.mga7
+ Revision: 1396344
- add patch to fix CVE-2019-9948 (mga#24758)

* Tue Apr 09 2019 daviddavid <daviddavid> 2.7.16-1.mga7
+ Revision: 1387322
- new version: 2.7.16
- add upstream patch to fix CVE-2019-9636 (mga#24640)
- use RPM built wheels of pip and setuptools in ensurepip instead of our rewheel patch

* Thu Mar 28 2019 daviddavid <daviddavid> 2.7.15-11.mga7
+ Revision: 1380719
- stdlib subpkg require main pkg (mga#24573)

* Tue Feb 12 2019 daviddavid <daviddavid> 2.7.15-10.mga7
+ Revision: 1365456
- add/rebase upstream patch to fix CVE-2019-5010 (mga#24340)

* Mon Dec 31 2018 wally <wally> 2.7.15-9.mga7
+ Revision: 1347598
- make libpython2.7-stdlib to not conflict with 64 bit version after multiarch support removal (from Fedora)

* Thu Dec 27 2018 daviddavid <daviddavid> 2.7.15-8.mga7
+ Revision: 1345322
- add two patches to fix CVE-2018-1000802 and CVE-2018-14647 (mga#23061)

* Thu Dec 27 2018 wally <wally> 2.7.15-7.mga7
+ Revision: 1345315
- drop multiarch support
- build using -fwrapv (and update other flags also)
- mangle .py shebangs by hand
- fix bytecompilation (do it manually)
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild
+ tmb <tmb>
- provide /usr/bin/python

* Sun Jun 17 2018 luigiwalser <luigiwalser> 2.7.15-6.mga7
+ Revision: 1237490
- rebuild for gdbm

* Wed May 23 2018 philippem <philippem> 2.7.15-5.mga7
+ Revision: 1231890
- fix CVE-2017-18207

* Tue May 08 2018 daviddavid <daviddavid> 2.7.15-4.mga7
+ Revision: 1227591
- provides python2-testsuite from testsuite sbpkg

* Wed May 02 2018 philippem <philippem> 2.7.15-3.mga7
+ Revision: 1224659
- Revert, don't remove dangles, this is a bug in rpm mga #22230

* Wed May 02 2018 philippem <philippem> 2.7.15-2.mga7
+ Revision: 1224658
- remove dangles mga#22230

* Tue May 01 2018 philippem <philippem> 2.7.15-1.mga7
+ Revision: 1224240
- update to 2.7.15

* Thu Apr 12 2018 philippem <philippem> 2.7.14-2.mga7
+ Revision: 1217995
- fix CVE-2018-1060
+ wally <wally>
- skip ctypes test on aarch64
- disable valgrind support on aarch64
- add aarch64 lib64 support

* Tue Dec 05 2017 josh <josh> 2.7.14-1.mga7
+ Revision: 1181426
- Update to new version
- Clean up obsolete patches
- Minimize tests to be excluded
- Update to new version
- Clean up obsolete patches
- Minimize tests to be excluded
+ tmb <tmb>
- rebuild for new readline

* Mon Aug 07 2017 ngompa <ngompa> 2.7.13-3.mga7
+ Revision: 1138243
- Add patch from Fedora to fix tests with OpenSSL 1.1
- Rebuild for new Python dependency generator

* Sat Jan 28 2017 philippem <philippem> 2.7.13-1.mga6
+ Revision: 1083777
- update to 2.7.13

* Sat Sep 10 2016 daviddavid <daviddavid> 2.7.12-4.mga6
+ Revision: 1051328
- rebuild to regenerate rpms (they were mistakenly replaced with those of Updates_testing)

* Sat Aug 13 2016 philippem <philippem> 2.7.12-3.mga6
+ Revision: 1046402
- fix CVE-2016-1000110

* Wed Jul 06 2016 tmb <tmb> 2.7.12-2.mga6
+ Revision: 1039104
- submit to release

* Mon Jul 04 2016 philippem <philippem> 2.7.12-1.mga6
+ Revision: 1038599
- update to 2.7.12

* Tue Jun 21 2016 philippem <philippem> 2.7.11-14.mga6
+ Revision: 1037112
- improve patch for zipimporter (mga#18691)

* Sun Jun 19 2016 philippem <philippem> 2.7.11-13.mga6
+ Revision: 1036799
- fix CVE-2016-0772 mga#18691

* Sun Jun 12 2016 philippem <philippem> 2.7.11-12.mga6
+ Revision: 1021227
- fix heap overflow in zipimporter module mga#18691
- add conflict for tkinter

* Mon Jun 06 2016 tv <tv> 2.7.11-11.mga6
+ Revision: 1020342
- unbloat installation:
  o remove recommends on tkinter-apps
  o move recommends on python-doc in devel package

* Sun Jun 05 2016 philippem <philippem> 2.7.11-10.mga6
+ Revision: 1020261
- conflict previous devel and new stdlib

* Fri Jun 03 2016 philippem <philippem> 2.7.11-9.mga6
+ Revision: 1020189
- remove idlelib from stdlib, it is in tkinter
- update provides and requires
- split in sub packages (mga#18561)
+ tv <tv>
- make devel package require macro packages

* Thu Mar 03 2016 umeabot <umeabot> 2.7.11-7.mga6
+ Revision: 983935
- Rebuild for openssl

* Tue Mar 01 2016 ovitters <ovitters> 2.7.11-6.mga6
+ Revision: 981720
- rebuild for new openssl

* Sat Feb 27 2016 philippem <philippem> 2.7.11-5.mga6
+ Revision: 980087
- remove macros now in python-rpm-macros

* Fri Feb 26 2016 tv <tv> 2.7.11-4.mga6
+ Revision: 979660
- actually apply patch 200

* Fri Feb 26 2016 tv <tv> 2.7.11-3.mga6
+ Revision: 979658
- patch 200: make platform supports Mageia
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Tue Dec 08 2015 philippem <philippem> 2.7.11-1.mga6
+ Revision: 908873
- update to 2.7.11

* Sun Nov 01 2015 pterjan <pterjan> 2.7.10-9.mga6
+ Revision: 897193
- Disable test_cmath on arm for now

* Thu Oct 29 2015 blino <blino> 2.7.10-8.mga6
+ Revision: 896467
- fix HTTPS connection with proxy (upstream patch, python#24311 and python#22095)

* Mon Oct 05 2015 daviddavid <daviddavid> 2.7.10-7.mga6
+ Revision: 886399
- rebuild for new tcl/tk 8.6.4

* Wed Sep 23 2015 daviddavid <daviddavid> 2.7.10-6.mga6
+ Revision: 882490
- fix %%{python2_version} macro as it give a wrong result: '2.' instead of '2.7'

* Sun Sep 06 2015 philippem <philippem> 2.7.10-5.mga6
+ Revision: 873284
- add new macros

* Fri Aug 21 2015 tmb <tmb> 2.7.10-4.mga6
+ Revision: 867691
- rebuild for new gcc

* Fri Aug 14 2015 joequant <joequant> 2.7.10-3.mga6
+ Revision: 864741
- add provides python2-devel to devel package

* Tue Jul 21 2015 philippem <philippem> 2.7.10-2.mga6
+ Revision: 855969
- add python2 macros

* Sun Jul 19 2015 philippem <philippem> 2.7.10-1.mga6
+ Revision: 855206
- update to 2.7.10

* Sat Dec 13 2014 philippem <philippem> 2.7.9-2.mga5
+ Revision: 802937
- fix security issues CVE-2014-9365 mga#14780

* Wed Oct 15 2014 umeabot <umeabot> 2.7.8-4.mga5
+ Revision: 747886
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2.7.8-3.mga5
+ Revision: 728012
- rebuild for missing pythoneggs deps
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Thu Aug 21 2014 philippem <philippem> 2.7.8-1.mga5
+ Revision: 666153
- update to 2.7.8

* Sat Jun 28 2014 philippem <philippem> 2.7.6-7.mga5
+ Revision: 640847
- fix CVE-2014-4650 and CVE-2014-4616 mga#15588)
+ pterjan <pterjan>
- Rebuild for new Python

* Thu Apr 10 2014 philippem <philippem> 2.7.6-5.mga5
+ Revision: 613314
- fix import tab-complete fail with ipython 2.0 shell

* Tue Mar 25 2014 philippem <philippem> 2.7.6-4.mga5
+ Revision: 608675
- fix readline module build

* Wed Mar 19 2014 philippem <philippem> 2.7.6-3.mga5
+ Revision: 605624
- fix sqlite-3.8.4 tests
- added patches for CVE-2013-1752 (mga#12127) issues that are
  missing in 2.7.6:
  python-2.7.6-imaplib.patch
  python-2.7.6-poplib.patch
  smtplib_maxline-2.7.patch
- CVE-2013-1753 (mga#13041) gzip decompression bomb in xmlrpc client:
  xmlrpc_gzip_27.patch

* Sat Feb 15 2014 philippem <philippem> 2.7.6-2.mga5
+ Revision: 592000
-fix buffer overflow CVE-2014-1912 with upstream patch

* Thu Feb 06 2014 fwang <fwang> 2.7.6-1.mga5
+ Revision: 584428
- rediff patch
- 2.7.6

* Tue Oct 22 2013 umeabot <umeabot> 2.7.5-11.mga4
+ Revision: 545491
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 2.7.5-10.mga4
+ Revision: 498057
- Rebuild to add different pythonegg provides for python 2 and 3

* Thu Sep 26 2013 fwang <fwang> 2.7.5-9.mga4
+ Revision: 486490
- drop conflicts could not be satisfied

* Wed Sep 25 2013 philippem <philippem> 2.7.5-8.mga4
+ Revision: 486298
+ rebuild (emptylog)

* Wed Sep 25 2013 fwang <fwang> 2.7.5-7.mga4
+ Revision: 485888
- versioned obsoletes

* Wed Sep 25 2013 fwang <fwang> 2.7.5-6.mga4
+ Revision: 485866
- add conflicts to ease upgrade

* Tue Sep 24 2013 philippem <philippem> 2.7.5-5.mga4
+ Revision: 485674
- remove PYTHONDONTWRITEBYTECODE=1 fix mga#3348
- profile.d files as configfile noreplace fix mga#10758

* Mon Aug 12 2013 oden <oden> 2.7.5-4.mga4
+ Revision: 465654
- P174: security fix for CVE-2013-4073 (upstream)

* Wed Jun 26 2013 philippem <philippem> 2.7.5-3.mga4
+ Revision: 447236
- Convert inconsistent indentation to spaces only to be in synch with python3 package

* Tue Jun 25 2013 philippem <philippem> 2.7.5-2.mga4
+ Revision: 446643
- Remove -Wl,--no-undefined in accordance with MGA #9395 and MGA #10102
- Remove -Wl,--no-undefined in Makefile in accordance with MGA #9395 and MGA #10102

* Tue May 28 2013 tv <tv> 2.7.5-1.mga4
+ Revision: 429662
- new release
- rediff patches

* Tue May 28 2013 tv <tv> 2.7.3-8.mga4
+ Revision: 429649
- make docs readable by !root...

* Sun Jan 13 2013 umeabot <umeabot> 2.7.3-7.mga3
+ Revision: 378425
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Aug 06 2012 luigiwalser <luigiwalser> 2.7.3-6.mga3
+ Revision: 278990
- rebuild for libffi

* Mon Jul 30 2012 tv <tv> 2.7.3-5.mga3
+ Revision: 276242
- rebuild for db-5.3

* Tue Jul 10 2012 luigiwalser <luigiwalser> 2.7.3-4.mga3
+ Revision: 269231
- add patch from rhel6 via mdv to verify that XML_SetHashSalt is in expat

* Mon Jun 18 2012 obgr_seneca <obgr_seneca> 2.7.3-3.mga3
+ Revision: 261795
- use system expat and ffi instead of bundled ones
- clean BRs
- Added patch for CVE-2011-4944 (Mga Bug #5843)

* Thu Jun 14 2012 tv <tv> 2.7.3-2.mga3
+ Revision: 260509
- build with db5.2

* Sun Apr 22 2012 wally <wally> 2.7.3-2.mga2
+ Revision: 232502
- fix _curses module build (mga#5524)

* Thu Apr 19 2012 fwang <fwang> 2.7.3-1.mga2
+ Revision: 231756
- update file list
- use xz tarball
- update file list
- new version 2.7.3
+ guillomovitch <guillomovitch>
- spec cleanup
- rename distribution-specific documentation file to README.mga

* Mon Dec 05 2011 fwang <fwang> 2.7.2-3.mga2
+ Revision: 176928
- add upstream patch to recognize gdbm 1.9 magic value
- build with gdbm
- rebuild for new gdbm

* Fri Sep 02 2011 tv <tv> 2.7.2-2.mga2
+ Revision: 137806
- make the huge doc subpackage be noarch

* Sat Jul 02 2011 fwang <fwang> 2.7.2-1.mga2
+ Revision: 117293
- br valgrind-devel
- new version 2.7.2

* Mon May 23 2011 misc <misc> 2.7.1-6.mga1
+ Revision: 100214
- do not duplicate line wth test ( especially since this mean some of them will be out of sync
- disable test_urllib2, as the test added by latest CVE do not seems to work ( at least on
  our builder bot ) and we are soon releasing
+ dmorgan <dmorgan>
- P26: security fix for CVE-2011-1521

* Thu May 05 2011 misc <misc> 2.7.1-5.mga1
+ Revision: 95183
- reuse mandriva patch made by Guillomovitch to fix mga#481

* Thu May 05 2011 misc <misc> 2.7.1-4.mga1
+ Revision: 95087
- update patch to make sure that semaphore are enabled ( 2nd attempt at bug 481 )

* Tue Apr 26 2011 wally <wally> 2.7.1-3.mga1
+ Revision: 91819
- fix desktop file names (mga#954)
- drop buildroot definition

* Thu Apr 14 2011 misc <misc> 2.7.1-2.mga1
+ Revision: 85334
- add fix for mageia bug 481, patch by Panos Christeas, to force
  detection of sem_open
+ rtp <rtp>
- fix ffi check on mips
- regenerate IN.py/DLFCN.py/... at build time to make sure they're fine on current arch
- fix arch detection
- disable float test on arm

* Sun Jan 16 2011 misc <misc> 2.7.1-1.mga1
+ Revision: 20497
- built without db2 support ( was dropped from fedora, and i do not really know
  why we keep it )
- remove old compatibility macros
+ blino <blino>
- imported package python


* Mon Nov 29 2010 Funda Wang <fwang@mandriva.org> 2.7.1-1mdv2011.0
+ Revision: 602975
- drop merged CVE patch
- X11-devel not required
- New version 2.7.1

* Thu Nov 04 2010 Funda Wang <fwang@mandriva.org> 2.7-8mdv2011.0
+ Revision: 593073
- fix conflicts

  + Michael Scherer <misc@mandriva.org>
    - revert patch as it was not applied upstream first, and as it change the API

* Wed Nov 03 2010 Paulo Andrade <pcpa@mandriva.com.br> 2.7-7mdv2011.0
+ Revision: 593024
- Add http://bugs.python.org/issue7689 correction

  + Funda Wang <fwang@mandriva.org>
    - python-devel not needed

* Sun Oct 31 2010 Funda Wang <fwang@mandriva.org> 2.7-6mdv2011.0
+ Revision: 591160
- more linkage fix
- BR python-devel for now
- link against dl also
- fix module link of ctypes
- move Makefile and pyconfig into main pkg as required by sysconfig.py

* Sat Oct 30 2010 Oden Eriksson <oeriksson@mandriva.com> 2.7-5mdv2011.0
+ Revision: 590456
- P23: security fix for CVE-2010-3493
- P24: security fix for CVE-2010-3492

* Sat Oct 30 2010 Anssi Hannula <anssi@mandriva.org> 2.7-4mdv2011.0
+ Revision: 590326
- apply current devel library naming policy to smoothen upgrades

* Fri Oct 29 2010 Michael Scherer <misc@mandriva.org> 2.7-3mdv2011.0
+ Revision: 590288
- add a provides on python(abi), macro taken by fedora, proposal by anssi to have a automated requires on the python version

* Fri Oct 29 2010 Funda Wang <fwang@mandriva.org> 2.7-2mdv2011.0
+ Revision: 589919
- really use correct patch from fedora
- add fedora patch to fix lib64 detecting

* Fri Oct 29 2010 Michael Scherer <misc@mandriva.org> 2.7-1mdv2011.0
+ Revision: 589889
- fix the test list exception
- fix the test name that should be disabled
- disable test_get_outputs, seems it requires that python 2.7 is installed on build host
- disable test_getsitepackages as it fail due to one of our patch, I need to fix the test
- update to 2.7
- enable wide unicode support ( fix mdv#48570 )
- remove patch applied upstream ( tcl 8.6, pymalloc, d 4.8 )
- remove patch no longer needed ( ctypes linkage )
- remove patch deviating too much from upstream and not accepted yet ( xz )
- update lib6' patch
- add patch for support of new autoconf
- reenable tests that were previously disable, as this doesn't cause problem anymore

* Wed Aug 25 2010 Funda Wang <fwang@mandriva.org> 2.6.6-1mdv2011.0
+ Revision: 573088
- new version 2.6.6

* Wed Jul 14 2010 Oden Eriksson <oeriksson@mandriva.com> 2.6.5-4mdv2011.0
+ Revision: 553383
- bump release
- P21: security fix for CVE-2010-2089
- note that P19 does NOT solve CVE-2008-5983, it's just a new api
  developers can use to fix similar problems, will be added in 2.6.6

  + Funda Wang <fwang@mandriva.org>
    - add upstream patch to build with 4.8
    - add patches fixing CVE-2008-5983 and CVE-2010-1634

* Mon Apr 05 2010 Funda Wang <fwang@mandriva.org> 2.6.5-2mdv2010.1
+ Revision: 531712
- rebuild for new openssl

  + Michael Scherer <misc@mandriva.org>
    - add a BuildConflicts for failling test

* Sat Mar 20 2010 Michael Scherer <misc@mandriva.org> 2.6.5-1mdv2010.1
+ Revision: 525430
- add exception for test_distutils ( as it requires python-devel )
- update to 2.6.5
- remove patch for CVE-2009-3560, merged upstream
- remove patch from Fedora, not approved upstream
- clean test exceptions
- update linkage patch for python 2.6.5

  + Oden Eriksson <oeriksson@mandriva.com>
    - rebuilt against openssl-0.9.8m

* Sat Jan 30 2010 Funda Wang <fwang@mandriva.org> 2.6.4-6mdv2010.1
+ Revision: 498510
- add patches from fedora to have it built and work with db4.8

* Mon Jan 25 2010 Michael Scherer <misc@mandriva.org> 2.6.4-5mdv2010.1
+ Revision: 496309
- re-add _bsddb.so, as it doesn't support db4.8, spotted by bogdano

* Sun Jan 17 2010 Michael Scherer <misc@mandriva.org> 2.6.4-4mdv2010.1
+ Revision: 492596
- link python with ncursesw, to fix canto crashing

* Sun Jan 10 2010 Oden Eriksson <oeriksson@mandriva.com> 2.6.4-3mdv2010.1
+ Revision: 488613
- P18: security fix for CVE-2009-3560

* Thu Dec 31 2009 Funda Wang <fwang@mandriva.org> 2.6.4-2mdv2010.1
+ Revision: 484292
- 2.6.4 docs
- rebuild for db 4.8

* Tue Oct 27 2009 Michael Scherer <misc@mandriva.org> 2.6.4-1mdv2010.0
+ Revision: 459569
- update doc
- update to latest version of python

* Tue Oct 06 2009 Michael Scherer <misc@mandriva.org> 2.6.3-1mdv2010.0
+ Revision: 454344
- disable test_distutils, as the test requires python-devel to be installed
- new bugfix release

* Sun Aug 23 2009 Oden Eriksson <oeriksson@mandriva.com> 2.6.2-4mdv2010.0
+ Revision: 419988
- bump release
- P18: security fix related to CVE-2009-2625

* Sat Jul 11 2009 Funda Wang <fwang@mandriva.org> 2.6.2-2mdv2010.0
+ Revision: 394776
- use -lpthread rather than -pthread

* Sat Jul 04 2009 Funda Wang <fwang@mandriva.org> 2.6.2-1mdv2010.0
+ Revision: 392298
- fix libdir
- fix /usr/lib
- fix typo
- fix desktop file
- Update linkage patch
- link on stdc++ is not needed, and it causes wrong link order
- update docs
- New version 2.6.2
- gdbm problem solved upstream
- rediff glibc and format string patch

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - no need to own subdirs of already owned dirs
    - ensure arch-independant tree is owned

  + Michael Scherer <misc@mandriva.org>
    - patch cleaning

* Sun Apr 12 2009 Gustavo De Nardin <gustavodn@mandriva.com> 2.6.1-6mdv2009.1
+ Revision: 366460
- P16: plural-fix, from Fedora, fixes gettext.py parsing of Plural-Forms:
  header (mdv bugs #49475, #44088)

* Wed Mar 04 2009 Gustavo De Nardin <gustavodn@mandriva.com> 2.6.1-5mdv2009.1
+ Revision: 348705
- fixed current UTF-8 proper name in locale.py, which fixes mdv bug #48158

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - add xz support to distutils (P14)

* Tue Feb 24 2009 Michael Scherer <misc@mandriva.org> 2.6.1-4mdv2009.1
+ Revision: 344595
- fix bug #47803, work around a urpmi behavior, idea from
  frederic himpe.

* Mon Jan 26 2009 Michael Scherer <misc@mandriva.org> 2.6.1-3mdv2009.1
+ Revision: 333792
- remove duplicated file from python packages

* Mon Jan 26 2009 Funda Wang <fwang@mandriva.org> 2.6.1-2mdv2009.1
+ Revision: 333679
- add back python-base versioned provides, as our rpm dep finder loves it

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - disable pymalloc when running under valgrind to make debugging with valgrind
      easier (P13)

* Tue Jan 06 2009 Jérôme Soyer <saispo@mandriva.org> 2.6.1-1mdv2009.1
+ Revision: 325462
- New upstream release
- New upstream release

* Sat Dec 27 2008 Adam Williamson <awilliamson@mandriva.org> 2.6-2mdv2009.1
+ Revision: 320034
- version the python-base obsolete
- don't require python-base since it doesn't exist any more

* Wed Dec 24 2008 Michael Scherer <misc@mandriva.org> 2.6-1mdv2009.1
+ Revision: 318324
- upgrade to python 2.6
- disable bytecode by default
- removal of python-base separation
- rediff and remove old patch
- add patch for ctypes format string error

* Fri Dec 19 2008 Adam Williamson <awilliamson@mandriva.org> 2.5.2-8mdv2009.1
+ Revision: 316264
- br db4-devel < 4.7 because it won't build against 4.7

* Fri Dec 19 2008 Michael Scherer <misc@mandriva.org> 2.5.2-7mdv2009.1
+ Revision: 316009
- add patch to build with new gcc check
- fix for new rpm, need to set the patch number

* Fri Dec 05 2008 Adam Williamson <awilliamson@mandriva.org> 2.5.2-6mdv2009.1
+ Revision: 310350
- rebuild for new tcl
- add tcl86.patch (fix for tcl 8.6)

  + Michael Scherer <misc@mandriva.org>
    - revert to 2.5.1 in svn for tcl/tk upgrade
    - obsoletes python-base
    - removal of the separation python/python-base
    - disable bytecode by default
    - update to python 2.6
    - remove all patchs applied upstream
    - rediff some patch ( mandriva detection, lib64 )

* Thu Sep 18 2008 Frederik Himpe <fhimpe@mandriva.org> 2.5.2-5mdv2009.0
+ Revision: 285713
- Add patch fixing security problem CVE-2008-4108

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - change %%patch to %%patch0 as %%patch is now a macro for rpm5

* Mon Aug 25 2008 Michael Scherer <misc@mandriva.org> 2.5.2-4mdv2009.0
+ Revision: 275801
- remove some test that fail, i have no time to investigate, but I need to update for security before release
- add patch for security fix of MDVSA-2008:163, fix for CVE-2008-1679, CVE-2008-2315, CVE-2008-2316, CVE-2008-3142, CVE-2008-3143 and CVE-2008-3144, fix bug #42305

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Tue Apr 15 2008 Gustavo De Nardin <gustavodn@mandriva.com> 2.5.2-3mdv2009.0
+ Revision: 194215
- security fix for Python-2.5.2's CVE-2008-1721

* Sat Mar 08 2008 Funda Wang <fwang@mandriva.org> 2.5.2-2mdv2008.1
+ Revision: 182067
- fix bug#9482, otherwise it reports redhat on mandriva system

* Wed Feb 27 2008 Michael Scherer <misc@mandriva.org> 2.5.2-1mdv2008.1
+ Revision: 175794
- make rpmlint happy, has the application are now in another rpm
- update to 2.5.2, bugfixs release
- rediff some patch

* Thu Jan 31 2008 Michael Scherer <misc@mandriva.org> 2.5.1-10mdv2008.1
+ Revision: 160818
- add patch for CVE-2007-4965 ( interget overflow in imageop ), fix bug #CVE-2007-4965
- add patch8, to reduce number of wakeup, come from fedora and upstream python, close #36743

* Wed Jan 02 2008 Götz Waschk <waschk@mandriva.org> 2.5.1-9mdv2008.1
+ Revision: 140361
- build bsddb module (bug #36317)

* Sat Dec 22 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.5.1-8mdv2008.1
+ Revision: 137221
- order prefix on profile scriptlets

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Fri Dec 21 2007 Oden Eriksson <oeriksson@mandriva.com> 2.5.1-7mdv2008.1
+ Revision: 136346
- rebuilt against new build deps

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - no executable bit on profile scriptlet

  + David Walluck <walluck@mandriva.org>
    - move README.mdk creation from %%install to %%prep
    - escape HOME variable and use macros in README.mdk

* Thu Sep 13 2007 Michael Scherer <misc@mandriva.org> 2.5.1-5mdv2008.0
+ Revision: 85044
- split tkinter in two, so idle is not installed by default
- fix menu for documentation ( bug #33441 )

* Fri Sep 07 2007 Anssi Hannula <anssi@mandriva.org> 2.5.1-4mdv2008.0
+ Revision: 82050
- rebuild for new soname of tcl

* Wed Sep 05 2007 Michael Scherer <misc@mandriva.org> 2.5.1-3mdv2008.0
+ Revision: 79761
- rebuild for new rpm-mandriva-setup

  + Thierry Vignaud <tv@mandriva.org>
    - kill desktop-file-validate's 'warning: key "Encoding" in group "Desktop Entry" is deprecated'

* Thu Aug 23 2007 Thierry Vignaud <tv@mandriva.org> 2.5.1-2mdv2008.0
+ Revision: 69368
- kill ldconfig require as requested by pixel
- kill file require

* Tue May 15 2007 Austin Acton <austin@mandriva.org> 2.5.1-1mdv2008.0
+ Revision: 27079
- buildrequires emacs

  + Michael Scherer <misc@mandriva.org>
    - update to 2.5.1


* Tue Dec 12 2006 Michael Scherer <misc@mandriva.org> 2.5-4mdv2007.0
+ Revision: 95126
- do not packages file twice in python and python-base ( error in python-2.4-base.list )
- rebuild with zlib, fix #27624 ( do not know why it happened in the first place )
- disable test that do not work, will see later why ( as they worked 2 weeks ago )
- add a comment to fix syntax highligthing with vim

* Mon Dec 11 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.5-3mdv2007.1
+ Revision: 94725
- 2.5-3mdv
- Merge from CS3-branch: ppc64 is a lib64 platform

* Tue Nov 28 2006 Michael Scherer <misc@mandriva.org> 2.5-2mdv2007.1
+ Revision: 87754
- adjust buildrequires, and bump release
- adjust tests :
  remove test_shutil as it fail in iurt ( remove /tmp/, i will have to take a closer look )
  reenable test_minidom, as it now work

* Tue Nov 28 2006 Michael Scherer <misc@mandriva.org> 2.5-1mdv2007.1
+ Revision: 87734
- disable test as they do not work in the buildbot. Let's move forward.
- try another workaround to make it compiles in buildbot, and rerun test in verbose mode if failed.
- andreas's suggestion, try a different TMP and TMPDIR, and be sure that it exist
- do not set TMP to /tmp, as it may cause issue with automated rebuilding
- Remove the other icons too, and remove the file from svn
- remove Icon, as it break repsys like this :
  error: Unable to open icon /home/misc/rpm/SOURCES/python-logo.xpm: No such file or directory
  error: query of specfile /tmp/tmp7KbWra/python.spec failed, can't parse
- replace python-ctypes and python-elementtree packages. No need for sqlite,
  we have a old version.
- add missing buildRequires, sqlite3-devel, now bundled with python 2.5
- add missing tarball
- update to python 2.5 ( not finished, i need to add some conflicts/obsoletes/provides )
- unzip patch
- Import python

